<?php
/**
 * Sauna Lite functions and definitions
 *
 * @package Sauna Lite
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */

if ( ! function_exists( 'sauna_lite_setup' ) ) :

/* Theme Setup */
function sauna_lite_setup() {

	$GLOBALS['content_width'] = apply_filters( 'sauna_lite_content_width', 640 );
	
	load_theme_textdomain( 'sauna-lite', get_template_directory() . '/languages' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'woocommerce' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'custom-logo', array(
		'height'      => 240,
		'width'       => 240,
		'flex-height' => true,
	) );
	add_image_size('sauna-lite-homepage-thumb',240,145,true);
	
       register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'sauna-lite' ),
	) );

	add_theme_support( 'custom-background', array(
		'default-color' => 'f1f1f1'
	) );

	/*
	* Enable support for Post Formats.
	*
	* See: https://codex.wordpress.org/Post_Formats
	*/
	add_theme_support( 'post-formats', array('image','video','gallery','audio',) );

	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, icons, and column width.
	 */
	
	add_editor_style( array( 'css/editor-style.css', sauna_lite_font_url() ) );

	// Dashboard Theme Notification
	global $pagenow;
	
	if ( is_admin() && ('themes.php' == $pagenow) && isset( $_GET['activated'] ) ) {
		add_action( 'admin_notices', 'sauna_lite_activation_notice' );
	}	
}
endif;
add_action( 'after_setup_theme', 'sauna_lite_setup' );

// Dashboard Theme Notification
function sauna_lite_activation_notice() {
	echo '<div class="welcome-notice notice notice-success is-dismissible">';
		echo '<h2>'. esc_html__( 'Thank You!!!!!', 'sauna-lite' ) .'</h2>';
		echo '<p>'. esc_html__( 'Much grateful to you for choosing our sauna theme from themescaliber. we praise you for opting our services over others. we are obliged to invite you on our welcome page to render you with our outstanding services.', 'sauna-lite' ) .'</p>';
		echo '<p><a href="'. esc_url( admin_url( 'themes.php?page=sauna_lite_guide' ) ) .'" class="button button-primary">'. esc_html__( 'Click Here...', 'sauna-lite' ) .'</a></p>';
	echo '</div>';
}

/* Theme Widgets Setup */
function sauna_lite_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'sauna-lite' ),
		'description'   => __( 'Appears on blog page sidebar', 'sauna-lite' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Page Sidebar', 'sauna-lite' ),
		'description'   => __( 'Appears on page sidebar', 'sauna-lite' ),
		'id'            => 'sidebar-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Thrid Column Sidebar', 'sauna-lite' ),
		'description'   => __( 'Appears on page sidebar', 'sauna-lite' ),
		'id'            => 'sidebar-3',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Navigation 1', 'sauna-lite' ),
		'description'   => __( 'Appears on footer', 'sauna-lite' ),
		'id'            => 'footer-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Navigation 2', 'sauna-lite' ),
		'description'   => __( 'Appears on footer', 'sauna-lite' ),
		'id'            => 'footer-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Navigation 3', 'sauna-lite' ),
		'description'   => __( 'Appears on footer', 'sauna-lite' ),
		'id'            => 'footer-3',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Navigation 4', 'sauna-lite' ),
		'description'   => __( 'Appears on footer', 'sauna-lite' ),
		'id'            => 'footer-4',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

}
add_action( 'widgets_init', 'sauna_lite_widgets_init' );

/* Theme Font URL */
function sauna_lite_font_url(){
	$font_url = '';
	$font_family = array();
	$font_family[] = 'PT Sans:300,400,600,700,800,900';
	$font_family[] = 'Roboto:400,700';
	$font_family[] = 'Roboto Condensed:400,700';
	$font_family[] = 'Montserrat:300,400,600,700,800,900';
	$font_family[] = 'Dancing Script';

	$query_args = array(
		'family'	=> urlencode(implode('|',$font_family)),
	);
	$font_url = add_query_arg($query_args,'//fonts.googleapis.com/css');
	return $font_url;
}
	
/* Theme enqueue scripts */
function sauna_lite_scripts() {
	wp_enqueue_style( 'sauna-lite-font', sauna_lite_font_url(), array() );	
	wp_enqueue_style( 'bootstrap', get_template_directory_uri().'/css/bootstrap.css' );
	wp_enqueue_style( 'sauna-lite-basic-style', get_stylesheet_uri() );
	wp_style_add_data( 'sauna-lite-style', 'rtl', 'replace' );
	wp_enqueue_style( 'sauna-lite-effect', get_template_directory_uri().'/css/effect.css' );
	wp_enqueue_style( 'font-awesome', get_template_directory_uri().'/css/fontawesome-all.css' );
	wp_enqueue_style( 'sauna-lite-customcss', get_template_directory_uri() . '/css/custom.css' );
	wp_enqueue_style( 'jquery-nivo-slider', get_template_directory_uri().'/css/nivo-slider.css' );
	wp_enqueue_script( 'jquery-nivo-slider', get_template_directory_uri() . '/js/jquery.nivo.slider.js', array('jquery') );	
	wp_enqueue_script( 'sauna-lite-customscripts', get_template_directory_uri() . '/js/custom.js', array('jquery') );
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	/* Enqueue the Dashicons script */
	wp_enqueue_style( 'dashicons' );
	wp_enqueue_style('sauna-lite-ie', get_template_directory_uri().'/css/ie.css', array('sauna-lite-basic-style'));
	wp_style_add_data( 'sauna-lite-ie', 'conditional', 'IE' );
}
add_action( 'wp_enqueue_scripts', 'sauna_lite_scripts' );

//Theme Url
define('SAUNA_LITE_FREE_THEME_DOC','https://themescaliber.com/doc/free-tc-sauna/','sauna-lite');
define('SAUNA_LITE_SUPPORT','https://wordpress.org/support/theme/sauna-lite/','sauna-lite');
define('SAUNA_LITE_REVIEW','https://www.themescaliber.com/topic/reviews-and-testimonials','sauna-lite');
define('SAUNA_LITE_BUY_NOW','https://www.themescaliber.com/premium/sauna-spa-wordpress-theme','sauna-lite');
define('SAUNA_LITE_LIVE_DEMO','https://www.themescaliber.com/sauna-theme/','sauna-lite');
define('SAUNA_LITE_PRO_DOC','https://themescaliber.com/doc/tc-sauna-pro/','sauna-lite');
define('SAUNA_LITE_CHILD_THEME','https://developer.wordpress.org/themes/advanced-topics/child-themes/','sauna-lite');
define('SAUNA_LITE_DEMO_DATA','https://www.themescaliber.com/doc/sauna-demo.xml.zip','sauna-lite');
define('SAUNA_LITE_CREDIT','https://www.themescaliber.com','sauna-lite');

if ( ! function_exists( 'sauna_lite_credit' ) ) {
	function sauna_lite_credit(){
		echo "<a href=".esc_url(SAUNA_LITE_CREDIT)." target='_blank'>". esc_html__('ThemesCaliber','sauna-lite'). "</a>";
	}
}

/*radio button sanitization*/
 function sauna_lite_sanitize_choices( $input, $setting ) {
    global $wp_customize; 
    $control = $wp_customize->get_control( $setting->id ); 
    if ( array_key_exists( $input, $control->choices ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

/* Custom template tags for this theme. */
require get_template_directory() . '/inc/template-tags.php';

/* Customizer additions. */
require get_template_directory() . '/inc/customizer.php';

/* Customizer additions. */
require get_template_directory() . '/inc/custom-header.php';

/* Implement the get started page */
require get_template_directory() . '/inc/dashboard/getstart.php';